fundamentals
=========================

.. image:: https://readthedocs.org/projects/fundamentals/badge/
    :target: http://fundamentals.readthedocs.io/en/latest/?badge
    :alt: Documentation Status

.. image:: https://cdn.rawgit.com/thespacedoctor/fundamentals/master/coverage.svg
    :target: https://cdn.rawgit.com/thespacedoctor/fundamentals/master/htmlcov/index.html
    :alt: Coverage Status

*Some project setup tools including logging, settings and database connections.*

Documentation
=============

Documentation for fundamentals is hosted by `Read the Docs <http://fundamentals.readthedocs.org/en/stable/>`__ (last `stable version <http://fundamentals.readthedocs.org/en/stable/>`__ and `latest version <http://fundamentals.readthedocs.org/en/latest/>`__).

Installation
============

The easiest way to install fundamentals is to use ``pip``:

.. code:: bash

    pip install fundamentals

Or you can clone the `github repo <https://github.com/thespacedoctor/fundamentals>`__ and install from a local version of the code:

.. code:: bash

    git clone git@github.com:thespacedoctor/fundamentals.git
    cd fundamentals
    python setup.py install

To upgrade to the latest version of fundamentals use the command:

.. code:: bash

    pip install fundamentals --upgrade


Development
-----------

If you want to tinker with the code, then install in development mode.
This means you can modify the code from your cloned repo:

.. code:: bash

    git clone git@github.com:thespacedoctor/fundamentals.git
    cd fundamentals
    python setup.py develop

`Pull requests <https://github.com/thespacedoctor/fundamentals/pulls>`__ are welcomed!


Issues
------

Please report any issues `here <https://github.com/thespacedoctor/fundamentals/issues>`__.



